@@ -20,7 +20,8 @@ import re
 from os import path
 from calculate.lib.datavars import Variable,VariableError,ReadonlyVariable, \
                                    TableVariable,PasswordError, \
-                                   ReadonlyTableVariable,FieldValue
+                                   ReadonlyTableVariable,FieldValue, \
+    DataVarsError
 from calculate.install.fs_manager import FileSystemManager
 from calculate.lib.utils.files import (readFile,getProgPath,process,
     readLinesFile)
@@ -34,7 +35,6 @@ from calculate.lib.encrypt import encrypt
 import calculate.lib.cl_template as cl_template
 
 from calculate.lib.cl_lang import setLocalTranslate
-from calculate.update.variables import update
 
 setLocalTranslate('cl_install3',sys.modules[__name__])
 
@@ -324,6 +324,9 @@ class VariableClAutologin(UserHelper,Variable):
             return ""
         return ""
 
+    def set(self, value):
+        return {'none':''}.get(value, value)
+
     def choice(self):
         return [""]+filter(lambda x:x != "root",self.Get('cl_migrate_user'))
 
@@ -339,6 +342,19 @@ class VariableClAutologin(UserHelper,Variable):
     def humanReadable(self):
         return self.Get() or _("Not used")
 
+    def uncompatible(self):
+        """
+        Network setting up unavailable for flash installation
+        """
+        try:
+            if (self.Get('cl_action') == 'merge' and
+                self.Get('client.cl_remote_host')):
+                return \
+                    _("The autologin is not available with domain workstations")
+        except DataVarsError:
+            pass
+        return ""
+
 class VariableClInstallAutoupdateSet(Variable):
     """
     (on or off) autoupdate config from install program for install
@@ -530,15 +546,17 @@ class VariableClSetup(Variable):
     value = ""
 
     def choice(self):
-        return ["audio","network","locale","video","boot","users",""]
+        return ["audio", "network", "locale", "video", "boot", "users",
+                "session", ""]
 
     def humanReadable(self):
-        mapType = {'network':_("network settings"),
-                   'locale':_("localization and time options"),
-                   'video':_("video settings"),
-                   'boot':_("boot parameters"),
-                   'audio':_("audio parameters"),
-                   'users':_("user settings") }
+        mapType = {'network': _("network settings"),
+                   'locale': _("localization and time options"),
+                   'video': _("video settings"),
+                   'boot': _("boot parameters"),
+                   'audio': _("audio parameters"),
+                   'session': _("session settings"),
+                   'users': _("user settings")}
         return mapType.get(self.Get(),"")
 
     def check(self,value):
@@ -728,11 +746,7 @@ class VariableOsInstallX11ServerSet(PackageCheckHelper):
     package = "x11-base/xorg-server"
 
 
-class VariableClInstallAutocheckSet(update.VariableClUpdateAutocheckSet):
-
-    def get(self):
-        return self.Get('update.cl_update_autocheck_set')
-
+class FlashUncompatible:
     def uncompatible(self):
         """
         Update setting up unavailable for flash installation
@@ -742,16 +756,38 @@ class VariableClInstallAutocheckSet(update.VariableClUpdateAutocheckSet):
                 _("Update configuration unavailable for Flash install")
         return ""
 
-class VariableClInstallAutocheckInterval(
-    update.VariableClUpdateAutocheckInterval):
-    def get(self):
-        return self.Get('update.cl_update_autocheck_interval')
+try:
+    import calculate.update.variables.update as update
 
-    def uncompatible(self):
-        """
-        Update setting up unavailable for flash installation
-        """
-        if self.Get('os_install_root_type') == 'flash':
-            return \
-                _("Update configuration unavailable for Flash install")
-        return ""
+    class VariableClInstallAutocheckSet(update.VariableClUpdateAutocheckSet,
+                                        FlashUncompatible):
+        def get(self):
+            return self.Get('update.cl_update_autocheck_set')
+
+    class VariableClInstallAutocheckInterval(
+            update.VariableClUpdateAutocheckInterval, FlashUncompatible):
+        def get(self):
+            return self.Get('update.cl_update_autocheck_interval')
+
+    class VariableClInstallCleanpkgSet(
+        update.VariableClUpdateCleanpkgSet, FlashUncompatible):
+        def get(self):
+            return self.Get('update.cl_update_cleanpkg_set')
+
+    class VariableClInstallOtherSet(
+        update.VariableClUpdateOtherSet, FlashUncompatible):
+        def get(self):
+            return self.Get('update.cl_update_other_set')
+
+except ImportError:
+    class VariableClInstallAutocheckSet(Variable, FlashUncompatible):
+        value = "off"
+
+    class VariableClInstallAutocheckInterval(Variable, FlashUncompatible):
+        value = ""
+
+    class VariableClInstallCleanpkgSet(Variable, FlashUncompatible):
+        value = "off"
+
+    class VariableClInstallOtherSet(Variable, FlashUncompatible):
+        value = "off"
