@@ -29,7 +29,8 @@ from calculate.core.server.func import WsdlBase
 from calculate.install.utils.cl_install import ClInstallAction
 from calculate.install.utils.cl_setup import (ClSetupAudioAction,
                 ClSetupLocaleAction,ClSetupVideoAction,ClSetupSystemAction,
-                ClSetupBootAction,ClSetupNetworkAction)
+                ClSetupBootAction,ClSetupNetworkAction,
+                ClSetupSessionAction)
 
 class Wsdl(WsdlBase):
     methods = [{
@@ -102,18 +103,20 @@ class Wsdl(WsdlBase):
                         'os_install_grub_terminal')),
             lambda group: group(_("Update"),
                             normal=('cl_install_autocheck_set',
-                                    'cl_install_autocheck_interval'))],
+                                    'cl_install_autocheck_interval',
+                                    'cl_install_cleanpkg_set',
+                                    'cl_install_other_set'))],
             # действие выводит информацию перед запуском
-        'brief':{'next':__("Perform"),
-                 'image':'finish',
-                 'name':__("Start installing")}},
+            'brief':{'next':__("Perform"),
+                     'image':'finish',
+                     'name':__("Start installing")}},
         # установка на Flash
         {
-        'method_name':"install_flash",
-        'category':__("Installation"),
-        'title':__("Flash Install"),
-        'image':'drive-removable-media-usb-pendrive,'\
-                'drive-removable-media-usb,media-flash',
+        'method_name': "install_flash",
+        'category': __("Installation"),
+        'title': __("Flash Install"),
+        'image': ('drive-removable-media-usb-pendrive,'
+                  'drive-removable-media-usb,media-flash'),
         'gui':True,
         'rights':['install'],
         'logic':{'Install':install.Install},
@@ -269,4 +272,26 @@ class Wsdl(WsdlBase):
                     'os_install_clock_timezone'),
             expert=('cl_templates_locate','cl_dispatch_conf',
                     'cl_verbose_set'),
-            next_label=_("Save"))]}]
+            next_label=_("Save"))]},
+        {
+        # настройка локали
+        'method_name':"setup_session",
+        'category':__("Configuration"),
+        'title':__("Session"),
+        'image':'session-properties',
+        'command':'cl-setup-session',
+        'gui':True,
+        'rights':['setupsession'],
+        'logic':{'Install':install.Install},
+        'action':ClSetupSessionAction,
+        'datavars':"install",
+        'native_error':(VariableError,DataVarsError,install.InstallError),
+        'setvars':{'cl_action!':'merge','cl_merge_pkg!':[None],
+                   'cl_merge_set!':"on",'cl_setup':'session'},
+        'groups':[
+            lambda group:group(_("Session"),
+            normal=('cl_autologin', 'cl_install_home_crypt_set'),
+            expert=('cl_templates_locate','cl_dispatch_conf',
+                    'cl_verbose_set'),
+            next_label=_("Save"))]}
+        ]
